@@ -9,7 +9,7 @@ Theme class and predefined themes.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -45,11 +45,11 @@ class Theme(object):
 
     .. note:: All colors must be defined with a tuple of 3 or 4 numbers in the formats:
 
-                  - (R,G,B)
-                  - (R,G,B,A)
+                - (R,G,B)
+                - (R,G,B,A)
 
-              Red (R), Green (G) and Blue (B) must be numbers between 0 and 255.
-              A means the alpha channel (opacity), if 0 the color is transparent, 100 means opaque.
+            Red (R), Green (G) and Blue (B) must be numbers between 0 and 255.
+            A means the alpha channel (opacity), if 0 the color is transparent, 100 means opaque.
 
     :param background_color: Menu background color
     :type background_color: tuple, list, :py:class:`pygame_menu.baseimage.BaseImage`
@@ -59,8 +59,10 @@ class Theme(object):
     :type cursor_selection_color: tuple, list
     :param focus_background_color: Color of the widget focus, this must be a tuple of 4 elements. Also must be transparent
     :type focus_background_color: tuple, list
-    :param menubar_close_button: Draw a back-box button on header to close the menu
+    :param menubar_close_button: Draw a back-box button on header to close the menu, if user moves through nested submenus this buttons turns to a back-arrow
     :type menubar_close_button: bool
+    :param scrollarea_outer_margin: Outer scoll area margin (px), the tuple is added to computed scroll area width/height, it can add an margin to bottom/right scrolls after widgets. If value less than 1 use percentage of width/height. Default (0,0). It cannot be negative values
+    :type scrollarea_outer_margin: tuple, list
     :param scrollbar_color: Scrollbars color
     :type scrollbar_color: tuple, list
     :param scrollbar_shadow: Indicate if a shadow is drawn on each scrollbar
@@ -119,7 +121,9 @@ class Theme(object):
     :type widget_font_size: int
     :param widget_margin: Horizontal and vertical margin of each element in Menu (px). Default (0,10)
     :type widget_margin: tuple, list
-    :param widget_offset: X,Y axis offset of widgets inside Menu (px). If value less than 1 use percentage of width/height. Default *(0, 0)*
+    :param widget_padding: Padding of the widget according to CSS rules. It can be a single digit, or a tuple of 2, 3 or 4 elements
+    :type widget_padding: int, float, tuple, list
+    :param widget_offset: X,Y axis offset of widgets within Menu (px) respect to top-left corner. If value less than 1 use percentage of width/height. Default (0,0). It cannot be negative values
     :type widget_offset: tuple, list
     :param widget_selection_effect: Widget selection effect object
     :type widget_selection_effect: :py:class:`pygame_menu.widgets.core.Selection`
@@ -134,6 +138,7 @@ class Theme(object):
     """
 
     def __init__(self, **kwargs):
+        
         self.background_color = self._get(kwargs, 'background_color',
                                           'color_image', (220, 220, 220))  # type: tuple
         self.cursor_color = self._get(kwargs, 'cursor_color',
@@ -144,6 +149,8 @@ class Theme(object):
                                                 'color', (0, 0, 0, 180))  # type: tuple
         self.menubar_close_button = self._get(kwargs, 'menubar_close_button',
                                               bool, True)  # type: bool
+        self.scrollarea_outer_margin = self._get(kwargs, 'scrollarea_outer_margin',
+                                                 'tuple2', (0, 0))  # type: tuple
         self.scrollbar_color = self._get(kwargs, 'scrollbar_color',
                                          'color', (220, 220, 220))  # type: tuple
         self.scrollbar_shadow = self._get(kwargs, 'scrollbar_shadow',
@@ -194,22 +201,21 @@ class Theme(object):
                                                  'color_image_none')  # type: (tuple, type(None))
         self.widget_background_inflate = self._get(kwargs, 'background_inflate',
                                                    'tuple2', (16, 8))  # type: tuple
-        self.widget_font_antialias = self._get(kwargs,
-                                               'widget_font_antialias',
+        self.widget_font_antialias = self._get(kwargs, 'widget_font_antialias',
                                                bool, True)  # type: bool
-        self.widget_font_background_color_from_menu = self._get(kwargs,
-                                                                'widget_font_background_color_from_menu',
-                                                                bool, pygame.vernum.major == 2)  # type: bool
+        self.widget_font_background_color_from_menu = self._get(kwargs, 'widget_font_background_color_from_menu',
+                                                                bool, pygame.vernum[0] == 2)  # type: bool
         self.widget_font_color = self._get(kwargs, 'widget_font_color',
                                            'color', (70, 70, 70))  # type: tuple
         self.widget_font_size = self._get(kwargs, 'widget_font_size',
                                           int, 30)  # type: int
         self.widget_margin = self._get(kwargs, 'widget_margin',
                                        'tuple2', (0, 10))  # type: tuple
+        self.widget_padding = self._get(kwargs, 'widget_padding',
+                                        (int, float), 0)  # type: (int,float,tuple)
         self.widget_offset = self._get(kwargs, 'widget_offset',
                                        'tuple2', (0, 0))  # type: tuple
-        self.widget_selection_effect = self._get(kwargs, 'widget_selection_effect',
-                                                 _widgets.core.Selection,
+        self.widget_selection_effect = self._get(kwargs, 'widget_selection_effect', _widgets.core.Selection,
                                                  _widgets.HighlightSelection())  # type: _widgets.core.Selection
         self.widget_shadow = self._get(kwargs, 'widget_shadow',
                                        bool, False)  # type: bool
@@ -242,8 +248,6 @@ class Theme(object):
         assert self.title_font_size > 0, 'title font size must be greater than zero'
         assert self.widget_font_size > 0, 'widget font size must be greater than zero'
         assert self.widget_shadow_offset > 0, 'widget shadow offset must be greater than zero'
-        assert self.widget_offset[0] >= 0 and self.widget_offset[1] >= 0, \
-            'widget offset must be greater or equal than zero'
 
         # Format colors, this converts all color lists to tuples automatically
         self.background_color = self._format_opacity(self.background_color)  # type: tuple
@@ -262,10 +266,20 @@ class Theme(object):
         self.widget_font_color = self._format_opacity(self.widget_font_color)  # type: tuple
 
         # List to tuple
-        self.title_offset = self._vec_2tuple(self.title_offset)  # type: tuple
-        self.widget_background_inflate = self._vec_2tuple(self.widget_background_inflate)  # type: tuple
-        self.widget_margin = self._vec_2tuple(self.widget_margin)  # type: tuple
-        self.widget_offset = self._vec_2tuple(self.widget_offset)  # type: tuple
+        self.scrollarea_outer_margin = self._vec_to_tuple(self.scrollarea_outer_margin, 2)  # type: tuple
+        self.title_offset = self._vec_to_tuple(self.title_offset, 2)  # type: tuple
+        self.widget_background_inflate = self._vec_to_tuple(self.widget_background_inflate, 2)  # type: tuple
+        self.widget_margin = self._vec_to_tuple(self.widget_margin, 2)  # type: tuple
+        if isinstance(self.widget_padding, (list, tuple)):
+            self.widget_padding = self._vec_to_tuple(self.widget_padding)  # type: tuple
+            assert 2 <= self.widget_padding <= 4, 'widget padding tuple length must be 2, 3 or 4'
+        self.widget_offset = self._vec_to_tuple(self.widget_offset, 2)  # type: tuple
+
+        # Check sizes
+        assert self.scrollarea_outer_margin[0] >= 0 and self.scrollarea_outer_margin[1] >= 0, \
+            'scrollarea outer margin must be greater or equal than zero'
+        assert self.widget_offset[0] >= 0 and self.widget_offset[1] >= 0, \
+            'widget offset must be greater or equal than zero'
 
         # Configs
         self.widget_selection_effect.set_color(self.selection_color)
@@ -288,21 +302,26 @@ class Theme(object):
                                  self.background_color[2], int(opacity * 255))  # type: tuple
 
     @staticmethod
-    def _vec_2tuple(obj):
+    def _vec_to_tuple(obj, check_length=0):
         """
         Return a tuple from a list or tuple object.
 
         :param obj: Object
         :type obj: list, tuple
+        :param check_length: Check length if not zero
         :return: Tuple
         :rtype: tuple
         """
         if isinstance(obj, tuple):
-            return obj
+            v = obj
         elif isinstance(obj, list):
-            return obj[0], obj[1]
+            v = tuple(obj)
         else:
-            raise ValueError('object is not a 2 vector')
+            raise ValueError('object is not a vector')
+        if check_length > 0:
+            if len(v) != check_length:
+                raise ValueError('object is not a {0}-length vector'.format(check_length))
+        return v
 
     def copy(self):
         """
@@ -420,7 +439,6 @@ THEME_BLUE = Theme(
     scrollbar_shadow=True,
     scrollbar_slider_color=(150, 200, 230),
     scrollbar_slider_pad=2,
-    scrollbar_thick=14,
     selection_color=(100, 62, 132),
     title_background_color=(62, 149, 195),
     title_font_color=(228, 230, 246),
