@@ -9,7 +9,7 @@ Utility functions.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -30,9 +30,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+import sys
+
+import types
+import functools
+
 import pygame
 import pygame_menu.locals as _locals
-import sys
 
 
 def assert_alignment(align):
@@ -176,6 +180,18 @@ def make_surface(width, height, alpha=False, fill_color=None):
     return surface
 
 
+def is_callable(func):
+    """
+    Return true if ``func`` is callable.
+
+    :param func: Function object
+    :type func: any
+    :return: Bool
+    :rtype: bool
+    """
+    return isinstance(func, (types.FunctionType, types.BuiltinFunctionType, types.MethodType, functools.partial))
+
+
 def to_string(s, strict=False):
     """
     Check if string, if not convert. See issue #215.
