@@ -9,7 +9,7 @@ Base class for widgets.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -36,7 +36,8 @@ import pygame_menu.font as _fonts
 import pygame_menu.locals as _locals
 from pygame_menu.widgets.core.selection import Selection
 from pygame_menu.sound import Sound
-from pygame_menu.utils import make_surface, assert_alignment, assert_color, assert_position, assert_vector2, to_string
+from pygame_menu.utils import make_surface, assert_alignment, assert_color, assert_position, assert_vector2, \
+    to_string, is_callable
 
 from uuid import uuid4
 import time
@@ -50,9 +51,9 @@ class Widget(object):
     :type title: str
     :param widget_id: Widget identifier
     :type widget_id: str
-    :param onchange: Callback when changing the selector
-    :type onchange: function, None
-    :param onreturn: Callback when pressing return button
+    :param onchange: Callback when updating the status of the widget, executed in ``widget.change()``
+    :type onchange: callable, None
+    :param onreturn: Callback when applying on the widget (return), executed in ``widget.apply()``
     :type onreturn: callable, None
     :param args: Optional arguments for callbacks
     :type args: any
@@ -70,9 +71,9 @@ class Widget(object):
                  ):
         assert isinstance(widget_id, str)
         if onchange:
-            assert callable(onchange), 'onchange must be callable or None'
+            assert is_callable(onchange), 'onchange must be callable or None'
         if onreturn:
-            assert callable(onreturn), 'onreturn must be callable or None'
+            assert is_callable(onreturn), 'onreturn must be callable or None'
 
         # Store id, if None or empty create new ID based on UUID
         if widget_id is None or len(widget_id) == 0:
@@ -83,6 +84,7 @@ class Widget(object):
         self._background_inflate = (0, 0)
         self._events = []  # type: list
         self._id = str(widget_id)
+        self._padding = (0, 0, 0, 0)  # top, right, bottom, left
         self._margin = (0.0, 0.0)  # type: tuple
         self._max_width = None  # type: (int,float)
         self._rect = pygame.Rect(0, 0, 0, 0)  # type: (pygame.Rect,None)
@@ -131,7 +133,9 @@ class Widget(object):
         # Stores the last render surface size, updated by _check_render_size_changed()
         self._last_render_surface_size = (0, 0)
 
-        self._selection_effect = None  # type: Selection
+        # Selection effect, for avoiding exception while getting object rect, NullSelection
+        # was created. Initially it was None
+        self._selection_effect = _NullSelection()  # type: Selection
 
         # Public attributes
         self.active = False  # Widget requests focus
@@ -142,6 +146,7 @@ class Widget(object):
         self.selection_effect_enabled = True  # Some widgets cannot have selection effect
         self.sound = Sound()  # type: Sound
         self.touchscreen_enabled = True
+        self.visible = True  # Use .show() or .hide() to modify this status
 
     def set_attribute(self, key, value):
         """
@@ -187,8 +192,8 @@ class Widget(object):
     def _render_hash_changed(self, *args):
         """
         This method checks if the widget must render because the inner variables changed.
-        This method should include all the variables.
-        If the render changed,
+        This method should include all the variables used by the render method, for example,
+        visibility, selected, etc.
 
         :param args: Variables to check the hash
         :type args: any
@@ -236,7 +241,7 @@ class Widget(object):
         if color is not None:
             if isinstance(color, _baseimage.BaseImage):
                 assert color.get_drawing_mode() == _baseimage.IMAGE_MODE_FILL, \
-                    'currently widget only support IMAGE_MODE_FILL drawing mode'
+                    'currently widget only supports IMAGE_MODE_FILL drawing mode'
             else:
                 assert_color(color)
         assert_vector2(inflate)
@@ -292,7 +297,7 @@ class Widget(object):
 
         .. code-block:: python
 
-            callback_func( value, *args, *widget._args, **widget._kwargs )
+            callback_func(value, *args, *widget._args, **widget._kwargs)
 
         with:
             - ``value`` (if something is returned by ``get_value()``)
@@ -319,7 +324,7 @@ class Widget(object):
 
         .. code-block:: python
 
-            callback_func( value, *args, *widget._args, **widget._kwargs )
+            callback_func(value, *args, *widget._args, **widget._kwargs)
 
         with:
             - ``value`` (if something is returned by ``get_value()``)
@@ -363,7 +368,7 @@ class Widget(object):
 
     def set_max_width(self, width):
         """
-        Set widget max width (column support) if force_fit_text is enabled.
+        Set widget max width (column support) if ``force_fit_text`` is enabled.
 
         :param width: Width in px, None if max width is disabled
         :type width: int, float, None
@@ -377,18 +382,18 @@ class Widget(object):
         """
         Return the widget margin.
 
-        :return: Widget margin
+        :return: Widget margin (left, top)
         :rtype: tuple
         """
         return self._margin
 
     def set_margin(self, x, y):
         """
-        Set Widget margin.
+        Set Widget margin (left, top).
 
-        :param x: Margin on x axis
+        :param x: Margin on x axis (left)
         :type x: int, float
-        :param y: Margin on y axis
+        :param y: Margin on y axis (top)
         :type y: int, float
         :return: None
         """
@@ -396,6 +401,48 @@ class Widget(object):
         assert isinstance(y, (int, float))
         self._margin = (x, y)
 
+    def get_padding(self):
+        """
+        Return the widget padding.
+
+        :return: Widget padding (top, right, bottom, left)
+        :rtype: tuple
+        """
+        return self._padding
+
+    def set_padding(self, padding):
+        """
+        Set the Widget padding according to CSS rules.
+
+        - If an integer or float is provided: top, right, bottom and left values will be the same
+        - If 2-item tuple is provided: top and bottom takes the first value, left and right the second
+        - If 3-item tuple is provided: top will take the first value, left and right the second, and bottom the third
+        - If 4-item tuple is provided: padding will be (top, right, bottom, left)
+
+        .. note:: See `CSS W3Schools <https://www.w3schools.com/css/css_padding.asp>`_ for more info about padding.
+
+        :param padding: Can be a single number, or a tuple of 2, 3 or 4 elements following CSS style
+        :type padding: int, float, tuple, list
+        :return: None
+        """
+        assert isinstance(padding, (int, float, tuple, list))
+        if isinstance(padding, (int, float)):
+            assert padding >= 0, 'padding cant be a negative number'
+            self._padding = (padding, padding, padding, padding)
+        else:
+            assert 1 <= len(padding) <= 4, 'padding must be a tuple of 2, 3 or 4 elements'
+            for i in range(len(padding)):
+                assert isinstance(padding[i], (int, float)), 'all padding elements must be integers or floats'
+                assert padding[i] >= 0, 'all padding elements must be equal or greater than zero'
+            if len(padding) == 1:
+                self._padding = (padding[0], padding[0], padding[0], padding[0])
+            elif len(padding) == 2:
+                self._padding = (padding[0], padding[1], padding[0], padding[1])
+            elif len(padding) == 3:
+                self._padding = (padding[0], padding[1], padding[2], padding[1])
+            else:
+                self._padding = (padding[0], padding[1], padding[2], padding[3])
+
     def get_rect(self):
         """
         Return the Rect object, this forces the widget rendering.
@@ -404,7 +451,10 @@ class Widget(object):
         :rtype: :py:class:`pygame.Rect`
         """
         self._render()
-        return self._rect.copy()
+        return pygame.Rect(int(self._rect.x - self._padding[3]),
+                           int(self._rect.y - self._padding[0]),
+                           int(self._rect.width + self._padding[3] + self._padding[1]),
+                           int(self._rect.height + self._padding[0] + self._padding[2]))
 
     def get_value(self):
         """
@@ -426,20 +476,35 @@ class Widget(object):
         """
         return self._id
 
+    def change_id(self, widget_id):
+        """
+        Change widget id.
+
+        :param widget_id: Widget ID
+        :type widget_id: str
+        :return: None
+        """
+        assert isinstance(widget_id, str)
+        if self._menu is not None:
+            # noinspection PyProtectedMember
+            self._menu._check_id_duplicated(widget_id)
+        self._id = widget_id
+
     def _render(self):
         """
         Render the widget surface.
 
-        This method shall update the attribute ``_surface`` with a pygame.Surface
+        This method shall update the attribute ``_surface`` with a :py:class:`pygame.Surface`
         representing the outer borders of the widget.
 
-        :return: None
+        :return: True if widget has rendered a new state, None if the widget has not changed, so render used a cache
+        :rtype: bool, None
         """
         raise NotImplementedError('override is mandatory')
 
     def _font_render_string(self, text, color=(0, 0, 0), use_background_color=True):
         """
-        Render text.
+        Render text. If the font is not defined returns a zero-width surface.
 
         :param text: Text to render
         :type text: str
@@ -463,15 +528,17 @@ class Widget(object):
         if not use_background_color:
             bgcolor = None
 
+        if self._font is None:
+            return make_surface(0, 0)
         return self._font.render(text, self._font_antialias, color, bgcolor)
 
     def _check_render_size_changed(self):
         """
         Check the size changed after rendering.
         This method should be used only on widgets that can change in size, or if the size
-        is changed during execution time (like set_title).
+        is changed during execution time (like ``set_title``).
         The update status (needs update if render size changed) is returned by
-        Widget.surface_needs_update() method.
+        ``Widget.surface_needs_update()`` method.
 
         :return: Boolean, if True the size changed
         :rtype: bool
@@ -496,9 +563,11 @@ class Widget(object):
         text = self._font_render_string(string, color)
 
         # Create surface
-        surface = make_surface(width=text.get_width(),
-                               height=text.get_height(),
-                               alpha=True)
+        surface = make_surface(
+            width=text.get_width(),
+            height=text.get_height(),
+            alpha=True
+        )
 
         # Draw shadow first
         if self._shadow:
@@ -518,7 +587,7 @@ class Widget(object):
         """
         Checks if the widget width/height has changed because events. If so, return true and
         set the status of the widget (menu widget position needs update) as false. This method
-        is used by .update() from Menu class.
+        is used by ``.update()`` from Menu class.
 
         :return: True if the widget position has changed by events after the rendering.
         :rtype: bool
@@ -532,8 +601,8 @@ class Widget(object):
         """
         Set the text font.
 
-        :param font: Name or list of names for font (see pygame.font.match_font for precise format)
-        :type font: str, list
+        :param font: Font name (see :py:class:`pygame.font.match_font` for precise format)
+        :type font: str
         :param font_size: Size of font in pixels
         :type font_size: int
         :param color: Text color
@@ -563,19 +632,57 @@ class Widget(object):
 
         self._apply_font()
 
+    def update_font(self, style):
+        """
+        Updates font. This method receives a style dict (non empty) containing the following keys:
+
+        - ``antialias``             Font antialias (bool)
+        - ``background_color``      Background color (tuple)
+        - ``color``                 Font color (tuple)
+        - ``name``                  Name of the font (str)
+        - ``selected_color``        Selected color (tuple)
+        - ``size``                  Size of the font (int)
+
+        .. note:: If a key is not defined it will be rewritten using current font style from ``.get_font_info()`` method.
+
+        :param style: Font style dict
+        :type style: dict
+        :return: None
+        """
+        assert isinstance(style, dict)
+        assert 1 <= len(style.keys()) <= 6
+        current_font = self.get_font_info()
+        for k in current_font.keys():
+            if k not in style.keys():
+                style[k] = current_font[k]
+        self.set_font(font=style['name'], font_size=style['size'], color=style['color'],
+                      selected_color=style['selected_color'], background_color=style['background_color'],
+                      antialias=style['antialias'])
+        self._render()
+
     def get_font_info(self):
         """
         Return a dict with the information of the widget font.
 
-        :return: Dict, keys: size (int), name (str), color (tuple), selected_color (tuple), antialias (bool)
+        Dict values:
+
+        - ``antialias``             Font antialias (bool)
+        - ``background_color``      Background color (tuple)
+        - ``color``                 Font color (tuple)
+        - ``name``                  Name of the font (str)
+        - ``selected_color``        Selected color (tuple)
+        - ``size``                  Size of the font (int)
+
+        :return: Dict
         :rtype: dict
         """
         return {
-            'size': self._font_size,
-            'name': self._font_name,
-            'color': self._font_color,
-            'selected_color': self._font_selected_color,
             'antialias': self._font_antialias,
+            'background_color': self._font_background_color,
+            'color': self._font_color,
+            'name': self._font_name,
+            'selected_color': self._font_selected_color,
+            'size': self._font_size
         }
 
     def set_menu(self, menu):
@@ -774,9 +881,11 @@ class Widget(object):
         """
         Set the value.
 
-        .. warning:: This method does not fire the callbacks as it is
-                     called programmatically. This behavior is deliberately
-                     chosen to avoid infinite loops.
+        .. warning::
+
+            This method does not fire the callbacks as it is
+            called programmatically. This behavior is deliberately
+            chosen to avoid infinite loops.
 
         :param value: Value to be set on the widget
         :type value: Object
@@ -825,3 +934,43 @@ class Widget(object):
             copy_events.append(e)
         self._events = []
         return copy_events
+
+    def show(self):
+        """
+        Set widget visible.
+
+        :return: None
+        """
+        self.visible = True
+        self._render()
+        if self._menu is not None:
+            # noinspection PyProtectedMember
+            self._menu._update_selection_if_hidden()
+
+    def hide(self):
+        """
+        Hides widget.
+
+        :return: None
+        """
+        self.visible = False
+        self._render()
+        if self._menu is not None:
+            # noinspection PyProtectedMember
+            self._menu._update_selection_if_hidden()
+
+
+class _NullSelection(Selection):
+    """
+    Null selection. It redefines NoneSelection because that class cannot be
+    imported.
+    """
+
+    def __init__(self):
+        super(_NullSelection, self).__init__(
+            margin_left=0, margin_right=0, margin_top=0, margin_bottom=0
+        )
+
+    # noinspection PyMissingOrEmptyDocstring
+    def draw(self, surface, widget):
+        return
