@@ -10,7 +10,7 @@ for entering and previewing colors in RGB and HEX format.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -56,9 +56,9 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
     :type input_underline: str
     :param cursor_color: Color of cursor
     :type cursor_color: tuple
-    :param onchange: Callback when changing the selector
+    :param onchange: Function when changing the values of the color text
     :type onchange: callable, None
-    :param onreturn: Callback when pressing return button
+    :param onreturn: Function when pressing return on the color text input
     :type onreturn: callable, None
     :param prev_size: Width of the previsualization box in terms of the height of the widget
     :type prev_size: int, float
@@ -86,7 +86,8 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
                  repeat_keys_interval_ms=80,
                  repeat_mouse_interval_ms=100,
                  *args,
-                 **kwargs):
+                 **kwargs
+                 ):
         assert isinstance(colorinput_id, str)
         assert isinstance(color_type, str)
         assert isinstance(input_separator, str)
@@ -277,11 +278,12 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
         self._previsualize_color(surface)
 
     def _render(self):
-        super(ColorInput, self)._render()
+        r = super(ColorInput, self)._render()
 
         # Maybe TextInput did not rendered, so this has to be changed
         self._rect.width, self._rect.height = self._surface.get_size()
         self._rect.width += self._prev_size * self._rect.height  # Adds the previsualization size to the box
+        return r
 
     # noinspection PyMissingOrEmptyDocstring
     def update(self, events):
