@@ -9,7 +9,7 @@ Image widget class, adds a simple image.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -38,8 +38,8 @@ class Image(Widget):
     """
     Image widget.
 
-    :param image_path: Path of the image
-    :type image_path: str
+    :param image_path: Path of the image or BaseImage object. If BaseImage object is provided drawing mode is not considered
+    :type image_path: str, BaseImage
     :param image_id: Image ID
     :type image_id: str
     :param angle: Angle of the image in degrees (clockwise)
@@ -50,19 +50,50 @@ class Image(Widget):
     :type scale_smooth: bool
     """
 
-    def __init__(self, image_path, image_id='', angle=0, scale=(1, 1), scale_smooth=True):
-        assert isinstance(image_path, str)
+    def __init__(self,
+                 image_path,
+                 image_id='',
+                 angle=0,
+                 scale=(1, 1),
+                 scale_smooth=True
+                 ):
+        assert isinstance(image_path, (str, BaseImage))
         assert isinstance(image_id, str)
         assert isinstance(angle, (int, float))
         assert isinstance(scale, (tuple, list))
         assert isinstance(scale_smooth, bool)
         super(Image, self).__init__(widget_id=image_id)
 
-        self._image = BaseImage(image_path)
-        self._image.rotate(angle)
-        self._image.scale(scale[0], scale[1], smooth=scale_smooth)
+        if isinstance(image_path, BaseImage):
+            self._image = image_path
+        else:
+            self._image = BaseImage(image_path)
+            self._image.rotate(angle)
+            self._image.scale(scale[0], scale[1], smooth=scale_smooth)
+
         self.selection_effect_enabled = False
 
+    def get_image(self):
+        """
+        Gets the BaseImage object from widget.
+
+        :return: Widget image
+        :rtype: BaseImage
+        """
+        return self._image
+
+    def set_image(self, image):
+        """
+        Set the BaseImage object from widget.
+
+        :param image: BaseImage object
+        :type image: BaseImage
+        :return: None
+        """
+        self._image = image
+        self._surface = None
+        self._render()
+
     def _apply_font(self):
         pass
 
@@ -73,9 +104,11 @@ class Image(Widget):
 
     def _render(self):
         if self._surface is not None:
-            return
+            return True
         self._surface = self._image.get_surface()
         self._rect.width, self._rect.height = self._surface.get_size()
+        if not self._render_hash_changed(self.visible):
+            return True
 
     # noinspection PyMissingOrEmptyDocstring
     def update(self, events):
