@@ -9,7 +9,7 @@ ScrollBar class, manage the selection in a range of values.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -40,13 +40,13 @@ class ScrollBar(Widget):
     """
     A scroll bar include 3 separate controls: a slider, scroll arrows, and a page control:
 
-        a. The slider provides a way to quickly go to any part of the document
+        a. The slider provides a way to quickly go to any part of the document.
         b. The scroll arrows are push buttons which can be used to accurately navigate
            to a particular place in a document.
         c. The page control is the area over which the slider is dragged (the scroll bar's
            background). Clicking here moves the scroll bar towards the click by one "page".
 
-    .. warning:: Arrows are not yet implemented
+    .. warning:: Arrows are not yet implemented.
 
     :param length: Length of the page control
     :type length: int
@@ -54,7 +54,7 @@ class ScrollBar(Widget):
     :type values_range: tuple, list
     :param scrollbar_id: Bar identifier
     :type scrollbar_id: str
-    :param orientation: Bar orientation ORIENTATION_HORIZONTAL/ORIENTATION_VERTICAL
+    :param orientation: Bar orientation ``ORIENTATION_HORIZONTAL``/``ORIENTATION_VERTICAL``
     :type orientation: str
     :param slider_pad: Space between slider and page control
     :type slider_pad: int, float
@@ -64,9 +64,7 @@ class ScrollBar(Widget):
     :type page_ctrl_thick: int, float
     :param page_ctrl_color: Page control color
     :type page_ctrl_color: tuple, list
-    :param onchange: Callback when changing the selector
-    :type onchange: callable, None
-    :param onreturn: Callback when pressing return button
+    :param onreturn: Callback when pressind and moving the scroll
     :type onreturn: callable, None
     """
 
@@ -79,10 +77,10 @@ class ScrollBar(Widget):
                  slider_color=(200, 200, 200),
                  page_ctrl_thick=20,
                  page_ctrl_color=(235, 235, 235),
-                 onchange=None,
                  onreturn=None,
                  *args,
-                 **kwargs):
+                 **kwargs
+                 ):
         assert isinstance(length, (int, float))
         assert isinstance(values_range, (tuple, list))
         assert values_range[1] > values_range[0], 'minimum value first is expected'
@@ -95,7 +93,6 @@ class ScrollBar(Widget):
 
         super(ScrollBar, self).__init__(
             widget_id=scrollbar_id,
-            onchange=onchange,
             onreturn=onreturn,
             args=args,
             kwargs=kwargs
@@ -209,8 +206,8 @@ class ScrollBar(Widget):
 
     def _render(self):
         if not self._render_hash_changed(self._rect.size, self._slider_rect.x, self._slider_rect.y,
-                                         self._slider_rect.width, self._slider_rect.height):
-            return
+                                         self._slider_rect.width, self._slider_rect.height, self.visible):
+            return True
 
         self._surface = make_surface(*self._rect.size)
         self._surface.fill(self._page_ctrl_color)
@@ -317,9 +314,12 @@ class ScrollBar(Widget):
         """
         Set the amount that the value changes by when the user click on the
         page control surface.
-        The length of the slider is related to this value, and typically
-        represents the proportion of the document area shown in a scrolling
-        view.
+
+        .. note::
+
+            The length of the slider is related to this value, and typically
+            represents the proportion of the document area shown in a scrolling
+            view.
 
         :param value: Page step
         :type value: int, float
