@@ -9,7 +9,7 @@ Text input class, this widget lets user to write text.
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
-Copyright 2017-2020 Pablo Pizarro R. @ppizarror
+Copyright 2017-2021 Pablo Pizarro R. @ppizarror
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -98,9 +98,9 @@ class TextInput(Widget):
     :type maxwidth: int
     :param maxwidth_dynamically_update: Dynamically update maxwidth depending on char size
     :type maxwidth_dynamically_update: bool
-    :param onchange: Callback when changing the selector
+    :param onchange: Callback when changing the text input
     :type onchange: callable, None
-    :param onreturn: Callback when pressing return button
+    :param onreturn: Callback when pressing return on the text input
     :type onreturn: callable, None
     :param password: Input string is displayed as a password
     :type password: bool
@@ -149,7 +149,8 @@ class TextInput(Widget):
                  text_ellipsis='...',
                  valid_chars=None,
                  *args,
-                 **kwargs):
+                 **kwargs
+                 ):
         assert isinstance(textinput_id, str)
         assert isinstance(input_type, str)
         assert isinstance(input_underline, str)
@@ -373,8 +374,8 @@ class TextInput(Widget):
         string = self._title + self._get_input_string()  # Render string
 
         if not self._render_hash_changed(self._menu.get_id(), string, self.selected, self._cursor_render,
-                                         self._selection_enabled, self.active):
-            return
+                                         self._selection_enabled, self.active, self.visible):
+            return True
 
         if self.selected:
             color = self._font_selected_color
